@@ -156,9 +156,13 @@ def get_hdc_result(hdc, hdc_side, score_home, score_away):
     return (hdc_side_win, return_factor)    
 
 def get_hdc_return(hdc_side_win, return_factor , play_side, play_amount):
-    if hdc_side_win == play_side:
-        return_factor = return_factor
+    if play_side == 'minus':
+        result = -1*int(play_amount)
+    elif hdc_side_win == play_side:
+        result = int(play_amount)*return_factor
     else:
-        return_factor = -1*return_factor
+        result = -1*int(play_amount)*return_factor
         
-    return int(play_amount)*return_factor
+        
+        
+    return result
